Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(10779)

Unified Diff: components/html_viewer/html_frame.h

Issue 1674903003: Extract shell methods from ApplicationImpl into a base class, and pass this to Initialize() instead. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@mojom
Patch Set: . Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/html_viewer/html_document_application_delegate.cc ('k') | components/html_viewer/html_frame.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/html_viewer/html_frame.h
diff --git a/components/html_viewer/html_frame.h b/components/html_viewer/html_frame.h
index 1d7e7c3bfe0721995b9737a410343250e44e8609..dab02ae884606aff2fb8166a8da3315f3e891fe7 100644
--- a/components/html_viewer/html_frame.h
+++ b/components/html_viewer/html_frame.h
@@ -37,8 +37,8 @@ class WebWidget;
}
namespace mojo {
-class ApplicationImpl;
class Rect;
+class Shell;
}
namespace mus {
@@ -231,8 +231,8 @@ class HTMLFrame : public blink::WebFrameClient,
// delegate.
HTMLFrame* GetFirstAncestorWithDelegate();
- // Returns the ApplicationImpl from the first ancestor with a delegate.
- mojo::ApplicationImpl* GetApp();
+ // Returns the Shell from the first ancestor with a delegate.
+ mojo::Shell* GetShell();
// Gets the server Frame to use for this frame.
web_view::mojom::Frame* GetServerFrame();
« no previous file with comments | « components/html_viewer/html_document_application_delegate.cc ('k') | components/html_viewer/html_frame.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698